@@ -433,7 +433,7 @@ class _SystemModelBase(object):
         for i, comps in enumerate(
             zip(self._dependent, self._exog, self._endog, self._instr, self._weights)
         ):
-            shapes = list(map(lambda a: a.shape[0], comps))
+            shapes = [a.shape[0] for a in comps]
             if min(shapes) != max(shapes):
                 raise ValueError(
                     "Dependent, exogenous, endogenous and "
@@ -595,9 +595,14 @@ class _SystemModelBase(object):
             assert self.formula is not None
             parser = SystemFormulaParser(self.formula, data=data, eval_env=eval_env)
             equations = parser.data
-        params = np.asarray(params)
-        if params.ndim == 1:
-            params = params[:, None]
+        params = np.atleast_2d(np.asarray(params))
+        if params.shape[0] == 1:
+            params = params.T
+        nx = int(sum([_x.shape[1] for _x in self._x]))
+        if params.shape[0] != nx:
+            raise ValueError(
+                f"Parameters must have {nx} elements; found {params.shape[0]}."
+            )
         loc = 0
         out = AttrDict()
         for i, label in enumerate(self._eq_labels):
@@ -682,10 +687,12 @@ class _SystemModelBase(object):
     ) -> Tuple[NDArray, NDArray, NDArray, NDArray]:
         """Core estimation routine for iterative GLS"""
         wy, wx, wxhat = self._wy, self._wx, self._wxhat
-        sigma = self._sigma
-        if sigma is None:
+
+        if self._sigma is None:
             sigma = eps.T @ eps / nobs
             sigma *= self._sigma_scale(debiased)
+        else:
+            sigma = self._sigma
         est_sigma = sigma
 
         if not full_cov:
@@ -805,7 +812,7 @@ class _SystemModelBase(object):
             )
 
         if debiased:
-            total_reg = np.sum(list(map(lambda s: s.shape[1], self._wx)))
+            total_reg = np.sum([s.shape[1] for s in self._wx])
             df_denom = len(self._wx) * nobs - total_reg
             wald = WaldTestStatistic(stat / df, null, df, df_denom=df_denom, name=name)
         else:
@@ -927,12 +934,12 @@ class _SystemModelBase(object):
         results["debiased"] = debiased
 
         total_ss = resid_ss = 0.0
-        resid = []
+        residuals = []
         for key in individual:
             total_ss += individual[key].total_ss
             resid_ss += individual[key].resid_ss
-            resid.append(individual[key].resid)
-        resid = np.hstack(resid)
+            residuals.append(individual[key].resid)
+        resid = np.hstack(residuals)
 
         results["resid_ss"] = resid_ss
         results["total_ss"] = total_ss
@@ -944,13 +951,13 @@ class _SystemModelBase(object):
         x = self._x
         k = len(x)
         loc = 0
-        fitted = []
+        fitted_vals = []
         for i in range(k):
             nb = x[i].shape[1]
             b = beta[loc : loc + nb]
-            fitted.append(x[i] @ b)
+            fitted_vals.append(x[i] @ b)
             loc += nb
-        fitted = np.hstack(fitted)
+        fitted = np.hstack(fitted_vals)
 
         results["fitted"] = fitted
 
@@ -993,8 +1000,8 @@ class _SystemModelBase(object):
         judge = 1 - (eps ** 2).sum() / (eps_const ** 2).sum()
         # Dhrymes
         tot_eps_const_sq = (eps_const ** 2).sum(0)
-        r2s = np.asarray(r2s)
-        dhrymes = (r2s * tot_eps_const_sq).sum() / tot_eps_const_sq.sum()
+        r2s_arr = np.asarray(r2s)
+        dhrymes = (r2s_arr * tot_eps_const_sq).sum() / tot_eps_const_sq.sum()
 
         # Berndt
         sigma_y = (eps_const.T @ eps_const / nobs) * self._sigma_scale(debiased)
@@ -1038,7 +1045,7 @@ class _SystemModelBase(object):
         eps = np.reshape(eps, (k, eps.shape[0] // k)).T
         cov_est = cov_estimator(
             self._wxhat,
-            gls_eps,
+            eps,
             sigma,
             full_sigma,
             gls=True,
@@ -1092,10 +1099,10 @@ class _SystemModelBase(object):
         )
 
         # wresid is different between GLS and OLS
-        wresid = []
+        wresiduals = []
         for individual_key in individual:
-            wresid.append(individual[individual_key].wresid)
-        wresid = np.hstack(wresid)
+            wresiduals.append(individual[individual_key].wresid)
+        wresid = np.hstack(wresiduals)
         results["wresid"] = wresid
         results["cov_estimator"] = cov_est
         results["cov_config"] = cov_est.cov_config
@@ -1239,7 +1246,7 @@ class _LSSystemModelBase(_SystemModelBase):
             raise ValueError("Unknown cov_type: {0}".format(cov_type))
         cov_type = COV_TYPES[cov_type]
         k = len(self._dependent)
-        col_sizes = [0] + list(map(lambda v: v.shape[1], self._x))
+        col_sizes = [0] + [v.shape[1] for v in self._x]
         col_idx = [int(i) for i in np.cumsum(col_sizes)]
         total_cols = col_idx[-1]
         self._construct_xhat()
@@ -1435,23 +1442,6 @@ class IV3SLS(_LSSystemModelBase):
             )
         return cls(equations)
 
-    @classmethod
-    def multivariate_ls(
-        cls,
-        dependent: ArrayLike,
-        exog: OptionalArrayLike = None,
-        endog: OptionalArrayLike = None,
-        instruments: OptionalArrayLike = None,
-    ) -> "IV3SLS":
-        """
-        Deprecated. Use multivariate_iv.
-        """
-        warnings.warn(
-            "multivariate_ls is deprecated and will be removed " "after July 24, 2020.",
-            FutureWarning,
-        )
-        return cls.multivariate_iv(dependent, exog, endog, instruments)
-
     @classmethod
     def from_formula(
         cls,
@@ -1884,8 +1874,9 @@ class IVSystemGMM(_SystemModelBase):
             w = blocked_inner_prod(wz, np.eye(k_total)) / nobs
         else:
             w = initial_weight
+        assert w is not None
         beta_last = beta = self._blocked_gmm(
-            wx, wy, wz, w=w, constraints=self.constraints
+            wx, wy, wz, w=cast(NDArray, w), constraints=self.constraints
         )
         _eps = []
         loc = 0
@@ -1904,12 +1895,14 @@ class IVSystemGMM(_SystemModelBase):
                 self._weight_est.sigma(eps, wx) if self._sigma is None else self._sigma
             )
             w = self._weight_est.weight_matrix(wx, wz, eps, sigma=sigma)
-            beta = self._blocked_gmm(wx, wy, wz, w=w, constraints=self.constraints)
+            beta = self._blocked_gmm(
+                wx, wy, wz, w=cast(NDArray, w), constraints=self.constraints
+            )
             delta = beta_last - beta
             if vinv is None:
                 winv = np.linalg.inv(w)
                 xpz = blocked_cross_prod(wx, wz, np.eye(k))
-                xpz = xpz / nobs
+                xpz = cast(NDArray, xpz / nobs)
                 v = (xpz @ winv @ xpz.T) / nobs
                 vinv = inv(v)
             norm = delta.T @ vinv @ delta
@@ -1943,7 +1936,16 @@ class IVSystemGMM(_SystemModelBase):
         eps = np.hstack(_eps)
         iters += 1
         return self._finalize_results(
-            beta, cov.cov, weps, eps, w, sigma, iters - 1, cov_type, cov_config, cov
+            beta,
+            cov.cov,
+            weps,
+            eps,
+            cast(np.ndarray, w),
+            sigma,
+            iters - 1,
+            cov_type,
+            cov_config,
+            cov,
         )
 
     @staticmethod
@@ -1959,10 +1961,10 @@ class IVSystemGMM(_SystemModelBase):
         xpz = blocked_cross_prod(x, z, np.eye(k))
         wi = np.linalg.inv(w)
         xpz_wi_zpx = xpz @ wi @ xpz.T
-        zpy = []
+        zpy_arrs = []
         for i in range(k):
-            zpy.append(z[i].T @ y[i])
-        zpy = np.vstack(zpy)
+            zpy_arrs.append(z[i].T @ y[i])
+        zpy = np.vstack(zpy_arrs)
         xpz_wi_zpy = xpz @ wi @ zpy
         params = _parameters_from_xprod(xpz_wi_zpx, xpz_wi_zpy, constraints=constraints)
 
@@ -2024,10 +2026,10 @@ class IVSystemGMM(_SystemModelBase):
         )
 
         # wresid is different between GLS and OLS
-        wresid = []
+        wresiduals = []
         for individual_key in individual:
-            wresid.append(individual[individual_key].wresid)
-        wresid = np.hstack(wresid)
+            wresiduals.append(individual[individual_key].wresid)
+        wresid = np.hstack(wresiduals)
         results["wresid"] = wresid
         results["wmat"] = wmat
         results["weight_type"] = self._weight_type
