@@ -11,6 +11,7 @@ from linearmodels.panel.data import PanelData
 from linearmodels.panel.model import PanelOLS, PooledOLS
 from linearmodels.panel.utility import AbsorbingEffectWarning
 from linearmodels.shared.exceptions import MemoryWarning
+from linearmodels.shared.hypotheses import WaldTestStatistic
 from linearmodels.shared.utility import AttrDict
 from linearmodels.tests.panel._utility import (
     access_attributes,
@@ -28,7 +29,7 @@ pytestmark = pytest.mark.filterwarnings(
 perc_missing = [0.0, 0.02, 0.20]
 has_const = [True, False]
 perms = list(product(perc_missing, datatypes, has_const))
-ids = list(map(lambda s: "-".join(map(str, s)), perms))
+ids = ["-".join(str(param) for param in perms) for perm in perms]
 
 
 @pytest.fixture(params=perms, ids=ids)
@@ -82,7 +83,7 @@ def singleton_data(request):
 
 
 const_perms = list(product(perc_missing, datatypes))
-const_ids = list(map(lambda s: "-".join(map(str, s)), const_perms))
+const_ids = ["-".join(str(val) for val in perm) for perm in const_perms]
 
 
 @pytest.fixture(params=const_perms, ids=const_ids)
@@ -256,7 +257,9 @@ def test_const_data_both_weights(const_data):
 
 
 def test_panel_no_effects(data):
-    res = PanelOLS(data.y, data.x).fit()
+    panel = PanelOLS(data.y, data.x)
+    assert panel._collect_effects().shape[1] == 0
+    res = panel.fit()
     res2 = PooledOLS(data.y, data.x).fit()
     assert_results_equal(res, res2)
 
@@ -1419,3 +1422,38 @@ def test_zero_endog():
     x = pd.DataFrame(x, index=mi, columns=["x"])
     y = pd.Series(y, index=mi, name="y")
     PanelOLS(y, x).fit()
+
+
+def test_f_after_drop():
+    rg = np.random.default_rng(918273645)
+    y = pd.Series(rg.standard_normal(1000))
+    a1 = np.arange(1000) % 10
+    a2 = np.arange(1000) // 100
+
+    x = pd.DataFrame(
+        {"x": rg.standard_normal(1000), "a1": a1, "a2": a2, "c": np.ones(1000)}
+    )
+    mi = pd.MultiIndex.from_product([list(range(100)), list(range(10))])
+    y.index = mi
+    x.index = mi
+    mod = PanelOLS(y, x, drop_absorbed=True, entity_effects=True, time_effects=True)
+    with pytest.warns(AbsorbingEffectWarning):
+        res = mod.fit()
+    assert isinstance(res.f_statistic, WaldTestStatistic)
+    assert isinstance(res.f_statistic_robust, WaldTestStatistic)
+    assert res.f_statistic.stat > 0
+    assert res.f_statistic_robust.stat > 0
+
+
+def test_predict_incorrect(data):
+    mod = PanelOLS(data.y, data.x)
+    res = mod.fit()
+    with pytest.raises(ValueError, match="exog does not have the correct"):
+        mod.predict(res.params.iloc[:-1], exog=data.x)
+    exog = np.asarray(data.x)
+    if exog.ndim == 3:
+        exog = exog[:-1]
+    else:
+        exog = exog[:, :-1]
+    with pytest.raises(ValueError, match="exog does not have the correct"):
+        mod.predict(res.params, exog=exog)
