@@ -7,9 +7,10 @@ from numpy.testing import assert_allclose
 from pandas import DataFrame, Series, concat
 from pandas.testing import assert_frame_equal, assert_series_equal
 import pytest
+import scipy.stats
 
 from linearmodels.iv.model import _OLS as OLS
-from linearmodels.shared.hypotheses import InvalidTestStatistic
+from linearmodels.shared.hypotheses import InvalidTestStatistic, WaldTestStatistic
 from linearmodels.shared.utility import AttrDict
 from linearmodels.system._utility import (
     blocked_column_product,
@@ -375,6 +376,10 @@ def test_gls_without_mv_ols_equiv(mvreg_data):
 def test_ols_against_gls(data):
     mod = SUR(data)
     res = mod.fit(method="gls")
+    if isinstance(data[list(data.keys())[0]], dict):
+        predictions = mod.predict(res.params, equations=data)
+        predictions2 = mod.predict(np.asarray(res.params)[:, None], equations=data)
+        assert_allclose(predictions, predictions2)
     sigma = res.sigma
     sigma_m12 = inv_matrix_sqrt(np.asarray(sigma))
     key = list(data.keys())[0]
@@ -688,6 +693,9 @@ def test_fitted(data):
 def test_predict(missing_data):
     mod = SUR(missing_data)
     res = mod.fit()
+    pred_no_missing = res.predict(equations=missing_data, missing=False, dataframe=True)
+    pred_missing = res.predict(equations=missing_data, missing=True, dataframe=True)
+    assert pred_missing.shape[0] <= pred_no_missing.shape[0]
     pred = res.predict()
     for key in pred:
         assert_series_equal(
@@ -779,3 +787,119 @@ def test_system_r2_direct():
     assert_allclose(ref, res.system_rsquared.mcelroy)
     ref = reference_berndt(res.resids, y)
     assert_allclose(ref, res.system_rsquared.berndt, atol=1e-3, rtol=1e-3)
+
+
+def direct_gls(eqns, scale):
+    y = []
+    x = []
+    for key in eqns:
+        y.append(eqns[key]["dependent"])
+        x.append(eqns[key]["exog"])
+    y = scale * np.vstack(y)
+    from scipy.sparse import csc_matrix
+
+    n, k = x[0].shape
+    _x = csc_matrix((len(x) * n, len(x) * k))
+    for i, val in enumerate(x):
+        _x[i * n : (i + 1) * n, i * k : (i + 1) * k] = val
+    from scipy.sparse.linalg import inv as spinv
+
+    b = spinv(_x.T @ _x) @ (_x.T @ y)
+    e = y - _x @ b
+    e = e.reshape((-1, n)).T
+    sigma = e.T @ e / n
+    omega_inv = np.kron(np.linalg.inv(sigma), np.eye(n))
+    b_gls = np.linalg.inv(_x.T @ omega_inv @ _x) @ (_x.T @ omega_inv @ y)
+    xpx = _x.T @ omega_inv @ _x / n
+    xpxi = np.linalg.inv(xpx)
+    e = y - _x @ b_gls
+    xe = (_x.T @ omega_inv).T * e
+    _xe = np.zeros((n, len(x) * k))
+    for i in range(len(x)):
+        _xe += xe[i * n : (i + 1) * n]
+    xeex = _xe.T @ _xe / n
+    cov = xpxi @ xeex @ xpxi / n
+    return b_gls, cov, xpx, xeex, _xe
+
+
+@pytest.mark.parametrize("method", ["ols", "gls"])
+@pytest.mark.parametrize("cov_type", ["unadjusted", "robust", "hac", "clustered"])
+def test_tvalues_homogeneity(method, cov_type):
+    eqns = generate_data(k=3)
+    mod = SUR(eqns)
+    kwargs = {}
+
+    base = direct_gls(eqns, 1)
+    base_tstat = np.squeeze(base[0]) / np.sqrt(np.diag(base[1]))
+    base_100 = direct_gls(eqns, 1 / 100)
+    base_100_tstat = np.squeeze(base_100[0]) / np.sqrt(np.diag(base_100[1]))
+    assert_allclose(base_tstat, base_100_tstat)
+
+    if cov_type == "hac":
+        kwargs["bandwidth"] = 1
+    elif cov_type == "clustered":
+        key0 = list(eqns.keys())[0]
+        nobs = eqns[key0]["dependent"].shape[0]
+        rs = np.random.RandomState(231823)
+        kwargs["clusters"] = rs.randint(0, nobs // 5, size=(nobs, 1))
+    res0 = mod.fit(method=method, cov_type=cov_type, **kwargs)
+    for key in eqns:
+        eqns[key]["dependent"] = eqns[key]["dependent"] / 100.0
+
+    mod = SUR(eqns)
+    res1 = mod.fit(method=method, cov_type=cov_type, **kwargs)
+    assert_allclose(res0.tstats, res1.tstats)
+    if cov_type == "robust" and method == "gls":
+        assert_allclose(res0.tstats, base_tstat)
+        assert_allclose(res1.tstats, base_100_tstat)
+
+
+@pytest.mark.parametrize("k", [1, 3])
+def test_brequsch_pagan(k):
+    eqns = generate_data(k=k)
+    mod = SUR(eqns)
+    res = mod.fit()
+    stat = res.breusch_pagan()
+    if k == 1:
+        assert isinstance(stat, InvalidTestStatistic)
+        assert "Breusch-Pagan" in str(stat)
+        assert np.isnan(stat.stat)
+        return
+    rho = np.asarray(res.resids.corr())
+    nobs = res.resids.shape[0]
+    direct = 0.0
+    for i in range(3):
+        for j in range(i + 1, 3):
+            direct += rho[i, j] ** 2
+    direct *= nobs
+    assert isinstance(stat, WaldTestStatistic)
+    assert_allclose(stat.stat, direct)
+    assert stat.df == 3
+    assert_allclose(stat.pval, 1.0 - scipy.stats.chi2(3).cdf(direct))
+    assert "Residuals are uncorrelated" in stat.null
+    assert "Breusch-Pagan" in str(stat)
+
+
+@pytest.mark.parametrize("k", [1, 3])
+def test_likelihood_ratio(k):
+    eqns = generate_data(k=k)
+    mod = SUR(eqns)
+    res = mod.fit()
+    stat = res.likelihood_ratio()
+    if k == 1:
+        assert isinstance(stat, InvalidTestStatistic)
+        assert "Likelihood Ratio Test" in str(stat)
+        assert np.isnan(stat.stat)
+        return
+    eps = np.asarray(res.resids)
+    sigma = eps.T @ eps / eps.shape[0]
+    nobs = res.resids.shape[0]
+    direct = np.linalg.slogdet(sigma * np.eye(k))[1]
+    direct -= np.linalg.slogdet(sigma)[1]
+    direct *= nobs
+    assert isinstance(stat, WaldTestStatistic)
+    assert_allclose(stat.stat, direct)
+    assert stat.df == 3
+    assert_allclose(stat.pval, 1.0 - scipy.stats.chi2(3).cdf(direct))
+    assert "Covariance is diagonal" in stat.null
+    assert "Likelihood Ratio Test" in str(stat)
